# Trajectory Manifold

[![Documentation](https://img.shields.io/badge/Documentation-Main-darkgreen)](https://www.helmuthnaumer.com/trajectory_manifold/)

This repository contains code around statistical estimation on the trajectory manifold.

It is intended to accompany a paper currently under review.

The directory `figures` contains code to reproduce the figures in the work, while the directory `examples` contains the quick start example from the documentation.
